## Past Chats

<webc-api-to-table api_path="/api/user-data/chats/chats-table"  ></webc-api-to-table>
<webc-api-to-json api_path="/api/user-data/chats/chats"         ></webc-api-to-json>

---- 

## API
<iframe width="100%" height="500" src="/api/user-data/docs"><iframe>
